# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: UserSessionGetActiveList.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2
from ighap_bot.proto import Global_pb2 as Global__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='UserSessionGetActiveList.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x1eUserSessionGetActiveList.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\x1a\x0cGlobal.proto\";\n\x18UserSessionGetActiveList\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\"\xe5\x03\n UserSessionGetActiveListResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12@\n\x07session\x18\x02 \x03(\x0b\x32/.proto.UserSessionGetActiveListResponse.Session\x1a\xdb\x02\n\x07Session\x12\x12\n\nsession_id\x18\x01 \x01(\x04\x12\x10\n\x08\x61pp_name\x18\x02 \x01(\t\x12\x0e\n\x06\x61pp_id\x18\x03 \x01(\r\x12\x19\n\x11\x61pp_build_version\x18\x04 \x01(\r\x12\x13\n\x0b\x61pp_version\x18\x05 \x01(\t\x12!\n\x08platform\x18\x06 \x01(\x0e\x32\x0f.proto.Platform\x12\x18\n\x10platform_version\x18\x07 \x01(\t\x12\x1d\n\x06\x64\x65vice\x18\x08 \x01(\x0e\x32\r.proto.Device\x12\x13\n\x0b\x64\x65vice_name\x18\t \x01(\t\x12!\n\x08language\x18\n \x01(\x0e\x32\x0f.proto.Language\x12\x0f\n\x07\x63ountry\x18\x0b \x01(\t\x12\x0f\n\x07\x63urrent\x18\x0c \x01(\x08\x12\x13\n\x0b\x63reate_time\x18\r \x01(\r\x12\x13\n\x0b\x61\x63tive_time\x18\x0e \x01(\r\x12\n\n\x02ip\x18\x0f \x01(\tB/\n\x0enet.iGap.protoB\x1dProtoUserSessionGetActiveListb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,Global__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_USERSESSIONGETACTIVELIST = _descriptor.Descriptor(
  name='UserSessionGetActiveList',
  full_name='proto.UserSessionGetActiveList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.UserSessionGetActiveList.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=86,
  serialized_end=145,
)


_USERSESSIONGETACTIVELISTRESPONSE_SESSION = _descriptor.Descriptor(
  name='Session',
  full_name='proto.UserSessionGetActiveListResponse.Session',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_id', full_name='proto.UserSessionGetActiveListResponse.Session.session_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='app_name', full_name='proto.UserSessionGetActiveListResponse.Session.app_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='proto.UserSessionGetActiveListResponse.Session.app_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='app_build_version', full_name='proto.UserSessionGetActiveListResponse.Session.app_build_version', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='app_version', full_name='proto.UserSessionGetActiveListResponse.Session.app_version', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='platform', full_name='proto.UserSessionGetActiveListResponse.Session.platform', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='platform_version', full_name='proto.UserSessionGetActiveListResponse.Session.platform_version', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='device', full_name='proto.UserSessionGetActiveListResponse.Session.device', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='device_name', full_name='proto.UserSessionGetActiveListResponse.Session.device_name', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='language', full_name='proto.UserSessionGetActiveListResponse.Session.language', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='country', full_name='proto.UserSessionGetActiveListResponse.Session.country', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='current', full_name='proto.UserSessionGetActiveListResponse.Session.current', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='create_time', full_name='proto.UserSessionGetActiveListResponse.Session.create_time', index=12,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='active_time', full_name='proto.UserSessionGetActiveListResponse.Session.active_time', index=13,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ip', full_name='proto.UserSessionGetActiveListResponse.Session.ip', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=286,
  serialized_end=633,
)

_USERSESSIONGETACTIVELISTRESPONSE = _descriptor.Descriptor(
  name='UserSessionGetActiveListResponse',
  full_name='proto.UserSessionGetActiveListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.UserSessionGetActiveListResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='session', full_name='proto.UserSessionGetActiveListResponse.session', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_USERSESSIONGETACTIVELISTRESPONSE_SESSION, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=148,
  serialized_end=633,
)

_USERSESSIONGETACTIVELIST.fields_by_name['request'].message_type = Request__pb2._REQUEST
_USERSESSIONGETACTIVELISTRESPONSE_SESSION.fields_by_name['platform'].enum_type = Global__pb2._PLATFORM
_USERSESSIONGETACTIVELISTRESPONSE_SESSION.fields_by_name['device'].enum_type = Global__pb2._DEVICE
_USERSESSIONGETACTIVELISTRESPONSE_SESSION.fields_by_name['language'].enum_type = Global__pb2._LANGUAGE
_USERSESSIONGETACTIVELISTRESPONSE_SESSION.containing_type = _USERSESSIONGETACTIVELISTRESPONSE
_USERSESSIONGETACTIVELISTRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_USERSESSIONGETACTIVELISTRESPONSE.fields_by_name['session'].message_type = _USERSESSIONGETACTIVELISTRESPONSE_SESSION
DESCRIPTOR.message_types_by_name['UserSessionGetActiveList'] = _USERSESSIONGETACTIVELIST
DESCRIPTOR.message_types_by_name['UserSessionGetActiveListResponse'] = _USERSESSIONGETACTIVELISTRESPONSE

UserSessionGetActiveList = _reflection.GeneratedProtocolMessageType('UserSessionGetActiveList', (_message.Message,), dict(
  DESCRIPTOR = _USERSESSIONGETACTIVELIST,
  __module__ = 'UserSessionGetActiveList_pb2'
  # @@protoc_insertion_point(class_scope:proto.UserSessionGetActiveList)
  ))
_sym_db.RegisterMessage(UserSessionGetActiveList)

UserSessionGetActiveListResponse = _reflection.GeneratedProtocolMessageType('UserSessionGetActiveListResponse', (_message.Message,), dict(

  Session = _reflection.GeneratedProtocolMessageType('Session', (_message.Message,), dict(
    DESCRIPTOR = _USERSESSIONGETACTIVELISTRESPONSE_SESSION,
    __module__ = 'UserSessionGetActiveList_pb2'
    # @@protoc_insertion_point(class_scope:proto.UserSessionGetActiveListResponse.Session)
    ))
  ,
  DESCRIPTOR = _USERSESSIONGETACTIVELISTRESPONSE,
  __module__ = 'UserSessionGetActiveList_pb2'
  # @@protoc_insertion_point(class_scope:proto.UserSessionGetActiveListResponse)
  ))
_sym_db.RegisterMessage(UserSessionGetActiveListResponse)
_sym_db.RegisterMessage(UserSessionGetActiveListResponse.Session)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\035ProtoUserSessionGetActiveList'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: UserLogin.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2
from ighap_bot.proto import Global_pb2 as Global__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='UserLogin.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x0fUserLogin.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\x1a\x0cGlobal.proto\"\xb8\x02\n\tUserLogin\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\r\n\x05token\x18\x02 \x01(\t\x12\x10\n\x08\x61pp_name\x18\x03 \x01(\t\x12\x0e\n\x06\x61pp_id\x18\x04 \x01(\r\x12\x19\n\x11\x61pp_build_version\x18\x05 \x01(\r\x12\x13\n\x0b\x61pp_version\x18\x06 \x01(\t\x12!\n\x08platform\x18\x07 \x01(\x0e\x32\x0f.proto.Platform\x12\x18\n\x10platform_version\x18\x08 \x01(\t\x12\x1d\n\x06\x64\x65vice\x18\t \x01(\x0e\x32\r.proto.Device\x12\x13\n\x0b\x64\x65vice_name\x18\n \x01(\t\x12!\n\x08language\x18\x0b \x01(\x0e\x32\x0f.proto.Language\x12\x15\n\rsymmetric_key\x18\x0c \x01(\x0c\"\xbd\x02\n\x11UserLoginResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x19\n\x11\x64\x65precated_client\x18\x02 \x01(\x08\x12\x1b\n\x13secondary_node_name\x18\x03 \x01(\t\x12\x18\n\x10update_available\x18\x04 \x01(\x08\x12+\n#chat_delete_message_for_both_period\x18\x05 \x01(\r\x12\x15\n\rwallet_active\x18\x06 \x01(\x08\x12\x12\n\nmpl_active\x18\x07 \x01(\x08\x12!\n\x19wallet_agreement_accepted\x18\x08 \x01(\x08\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\t \x01(\t\x12\x14\n\x0c\x63ontact_hash\x18\n \x01(\t\x12\x0c\n\x04role\x18\x0b \x01(\x05\x42 \n\x0enet.iGap.protoB\x0eProtoUserLoginb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,Global__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_USERLOGIN = _descriptor.Descriptor(
  name='UserLogin',
  full_name='proto.UserLogin',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.UserLogin.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='token', full_name='proto.UserLogin.token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='app_name', full_name='proto.UserLogin.app_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='proto.UserLogin.app_id', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='app_build_version', full_name='proto.UserLogin.app_build_version', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='app_version', full_name='proto.UserLogin.app_version', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='platform', full_name='proto.UserLogin.platform', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='platform_version', full_name='proto.UserLogin.platform_version', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='device', full_name='proto.UserLogin.device', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='device_name', full_name='proto.UserLogin.device_name', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='language', full_name='proto.UserLogin.language', index=10,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='symmetric_key', full_name='proto.UserLogin.symmetric_key', index=11,
      number=12, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=72,
  serialized_end=384,
)


_USERLOGINRESPONSE = _descriptor.Descriptor(
  name='UserLoginResponse',
  full_name='proto.UserLoginResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.UserLoginResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='deprecated_client', full_name='proto.UserLoginResponse.deprecated_client', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='secondary_node_name', full_name='proto.UserLoginResponse.secondary_node_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='update_available', full_name='proto.UserLoginResponse.update_available', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='chat_delete_message_for_both_period', full_name='proto.UserLoginResponse.chat_delete_message_for_both_period', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='wallet_active', full_name='proto.UserLoginResponse.wallet_active', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='mpl_active', full_name='proto.UserLoginResponse.mpl_active', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='wallet_agreement_accepted', full_name='proto.UserLoginResponse.wallet_agreement_accepted', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='access_token', full_name='proto.UserLoginResponse.access_token', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='contact_hash', full_name='proto.UserLoginResponse.contact_hash', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='role', full_name='proto.UserLoginResponse.role', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=387,
  serialized_end=704,
)

_USERLOGIN.fields_by_name['request'].message_type = Request__pb2._REQUEST
_USERLOGIN.fields_by_name['platform'].enum_type = Global__pb2._PLATFORM
_USERLOGIN.fields_by_name['device'].enum_type = Global__pb2._DEVICE
_USERLOGIN.fields_by_name['language'].enum_type = Global__pb2._LANGUAGE
_USERLOGINRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
DESCRIPTOR.message_types_by_name['UserLogin'] = _USERLOGIN
DESCRIPTOR.message_types_by_name['UserLoginResponse'] = _USERLOGINRESPONSE

UserLogin = _reflection.GeneratedProtocolMessageType('UserLogin', (_message.Message,), dict(
  DESCRIPTOR = _USERLOGIN,
  __module__ = 'UserLogin_pb2'
  # @@protoc_insertion_point(class_scope:proto.UserLogin)
  ))
_sym_db.RegisterMessage(UserLogin)

UserLoginResponse = _reflection.GeneratedProtocolMessageType('UserLoginResponse', (_message.Message,), dict(
  DESCRIPTOR = _USERLOGINRESPONSE,
  __module__ = 'UserLogin_pb2'
  # @@protoc_insertion_point(class_scope:proto.UserLoginResponse)
  ))
_sym_db.RegisterMessage(UserLoginResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\016ProtoUserLogin'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: GroupUpdateStatus.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2
from ighap_bot.proto import Global_pb2 as Global__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='GroupUpdateStatus.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x17GroupUpdateStatus.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\x1a\x0cGlobal.proto\"\x83\x01\n\x11GroupUpdateStatus\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x0f\n\x07room_id\x18\x02 \x01(\x04\x12\x12\n\nmessage_id\x18\x03 \x01(\x04\x12(\n\x06status\x18\x04 \x01(\x0e\x32\x18.proto.RoomMessageStatus\"\xc2\x01\n\x19GroupUpdateStatusResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x0f\n\x07room_id\x18\x02 \x01(\x04\x12\x12\n\nmessage_id\x18\x03 \x01(\x04\x12(\n\x06status\x18\x04 \x01(\x0e\x32\x18.proto.RoomMessageStatus\x12\x16\n\x0estatus_version\x18\x05 \x01(\x04\x12\x1b\n\x13updater_author_hash\x18\x06 \x01(\tB(\n\x0enet.iGap.protoB\x16ProtoGroupUpdateStatusb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,Global__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_GROUPUPDATESTATUS = _descriptor.Descriptor(
  name='GroupUpdateStatus',
  full_name='proto.GroupUpdateStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.GroupUpdateStatus.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='room_id', full_name='proto.GroupUpdateStatus.room_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message_id', full_name='proto.GroupUpdateStatus.message_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status', full_name='proto.GroupUpdateStatus.status', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=80,
  serialized_end=211,
)


_GROUPUPDATESTATUSRESPONSE = _descriptor.Descriptor(
  name='GroupUpdateStatusResponse',
  full_name='proto.GroupUpdateStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.GroupUpdateStatusResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='room_id', full_name='proto.GroupUpdateStatusResponse.room_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message_id', full_name='proto.GroupUpdateStatusResponse.message_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status', full_name='proto.GroupUpdateStatusResponse.status', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status_version', full_name='proto.GroupUpdateStatusResponse.status_version', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='updater_author_hash', full_name='proto.GroupUpdateStatusResponse.updater_author_hash', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=214,
  serialized_end=408,
)

_GROUPUPDATESTATUS.fields_by_name['request'].message_type = Request__pb2._REQUEST
_GROUPUPDATESTATUS.fields_by_name['status'].enum_type = Global__pb2._ROOMMESSAGESTATUS
_GROUPUPDATESTATUSRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_GROUPUPDATESTATUSRESPONSE.fields_by_name['status'].enum_type = Global__pb2._ROOMMESSAGESTATUS
DESCRIPTOR.message_types_by_name['GroupUpdateStatus'] = _GROUPUPDATESTATUS
DESCRIPTOR.message_types_by_name['GroupUpdateStatusResponse'] = _GROUPUPDATESTATUSRESPONSE

GroupUpdateStatus = _reflection.GeneratedProtocolMessageType('GroupUpdateStatus', (_message.Message,), dict(
  DESCRIPTOR = _GROUPUPDATESTATUS,
  __module__ = 'GroupUpdateStatus_pb2'
  # @@protoc_insertion_point(class_scope:proto.GroupUpdateStatus)
  ))
_sym_db.RegisterMessage(GroupUpdateStatus)

GroupUpdateStatusResponse = _reflection.GeneratedProtocolMessageType('GroupUpdateStatusResponse', (_message.Message,), dict(
  DESCRIPTOR = _GROUPUPDATESTATUSRESPONSE,
  __module__ = 'GroupUpdateStatus_pb2'
  # @@protoc_insertion_point(class_scope:proto.GroupUpdateStatusResponse)
  ))
_sym_db.RegisterMessage(GroupUpdateStatusResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\026ProtoGroupUpdateStatus'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: GeoGetConfiguration.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='GeoGetConfiguration.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x19GeoGetConfiguration.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"6\n\x13GeoGetConfiguration\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\"\xb6\x01\n\x1bGeoGetConfigurationResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x42\n\x0btile_server\x18\x02 \x03(\x0b\x32-.proto.GeoGetConfigurationResponse.TileServer\x12\x10\n\x08\x63\x61\x63he_id\x18\x03 \x01(\t\x1a\x1e\n\nTileServer\x12\x10\n\x08\x62\x61se_url\x18\x01 \x01(\tB*\n\x0enet.iGap.protoB\x18ProtoGeoGetConfigurationb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_GEOGETCONFIGURATION = _descriptor.Descriptor(
  name='GeoGetConfiguration',
  full_name='proto.GeoGetConfiguration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.GeoGetConfiguration.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=67,
  serialized_end=121,
)


_GEOGETCONFIGURATIONRESPONSE_TILESERVER = _descriptor.Descriptor(
  name='TileServer',
  full_name='proto.GeoGetConfigurationResponse.TileServer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base_url', full_name='proto.GeoGetConfigurationResponse.TileServer.base_url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=276,
  serialized_end=306,
)

_GEOGETCONFIGURATIONRESPONSE = _descriptor.Descriptor(
  name='GeoGetConfigurationResponse',
  full_name='proto.GeoGetConfigurationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.GeoGetConfigurationResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tile_server', full_name='proto.GeoGetConfigurationResponse.tile_server', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cache_id', full_name='proto.GeoGetConfigurationResponse.cache_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_GEOGETCONFIGURATIONRESPONSE_TILESERVER, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=124,
  serialized_end=306,
)

_GEOGETCONFIGURATION.fields_by_name['request'].message_type = Request__pb2._REQUEST
_GEOGETCONFIGURATIONRESPONSE_TILESERVER.containing_type = _GEOGETCONFIGURATIONRESPONSE
_GEOGETCONFIGURATIONRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_GEOGETCONFIGURATIONRESPONSE.fields_by_name['tile_server'].message_type = _GEOGETCONFIGURATIONRESPONSE_TILESERVER
DESCRIPTOR.message_types_by_name['GeoGetConfiguration'] = _GEOGETCONFIGURATION
DESCRIPTOR.message_types_by_name['GeoGetConfigurationResponse'] = _GEOGETCONFIGURATIONRESPONSE

GeoGetConfiguration = _reflection.GeneratedProtocolMessageType('GeoGetConfiguration', (_message.Message,), dict(
  DESCRIPTOR = _GEOGETCONFIGURATION,
  __module__ = 'GeoGetConfiguration_pb2'
  # @@protoc_insertion_point(class_scope:proto.GeoGetConfiguration)
  ))
_sym_db.RegisterMessage(GeoGetConfiguration)

GeoGetConfigurationResponse = _reflection.GeneratedProtocolMessageType('GeoGetConfigurationResponse', (_message.Message,), dict(

  TileServer = _reflection.GeneratedProtocolMessageType('TileServer', (_message.Message,), dict(
    DESCRIPTOR = _GEOGETCONFIGURATIONRESPONSE_TILESERVER,
    __module__ = 'GeoGetConfiguration_pb2'
    # @@protoc_insertion_point(class_scope:proto.GeoGetConfigurationResponse.TileServer)
    ))
  ,
  DESCRIPTOR = _GEOGETCONFIGURATIONRESPONSE,
  __module__ = 'GeoGetConfiguration_pb2'
  # @@protoc_insertion_point(class_scope:proto.GeoGetConfigurationResponse)
  ))
_sym_db.RegisterMessage(GeoGetConfigurationResponse)
_sym_db.RegisterMessage(GeoGetConfigurationResponse.TileServer)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\030ProtoGeoGetConfiguration'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: GroupAddAdmin.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='GroupAddAdmin.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x13GroupAddAdmin.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"\xab\x02\n\rGroupAddAdmin\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x0f\n\x07room_id\x18\x02 \x01(\x04\x12\x11\n\tmember_id\x18\x03 \x01(\x04\x12\x34\n\npermission\x18\x04 \x01(\x0b\x32 .proto.GroupAddAdmin.AdminRights\x1a\x9e\x01\n\x0b\x41\x64minRights\x12\x13\n\x0bmodify_room\x18\x01 \x01(\x08\x12\x16\n\x0e\x64\x65lete_message\x18\x02 \x01(\x08\x12\x13\n\x0bpin_message\x18\x03 \x01(\x08\x12\x12\n\nadd_member\x18\x04 \x01(\x08\x12\x12\n\nban_member\x18\x05 \x01(\x08\x12\x12\n\nget_member\x18\x06 \x01(\x08\x12\x11\n\tadd_admin\x18\x07 \x01(\x08\"\x94\x01\n\x15GroupAddAdminResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x0f\n\x07room_id\x18\x02 \x01(\x04\x12\x11\n\tmember_id\x18\x03 \x01(\x04\x12\x34\n\npermission\x18\x04 \x01(\x0b\x32 .proto.GroupAddAdmin.AdminRightsB$\n\x0enet.iGap.protoB\x12ProtoGroupAddAdminb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_GROUPADDADMIN_ADMINRIGHTS = _descriptor.Descriptor(
  name='AdminRights',
  full_name='proto.GroupAddAdmin.AdminRights',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='modify_room', full_name='proto.GroupAddAdmin.AdminRights.modify_room', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='delete_message', full_name='proto.GroupAddAdmin.AdminRights.delete_message', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pin_message', full_name='proto.GroupAddAdmin.AdminRights.pin_message', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='add_member', full_name='proto.GroupAddAdmin.AdminRights.add_member', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ban_member', full_name='proto.GroupAddAdmin.AdminRights.ban_member', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='get_member', full_name='proto.GroupAddAdmin.AdminRights.get_member', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='add_admin', full_name='proto.GroupAddAdmin.AdminRights.add_admin', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=203,
  serialized_end=361,
)

_GROUPADDADMIN = _descriptor.Descriptor(
  name='GroupAddAdmin',
  full_name='proto.GroupAddAdmin',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.GroupAddAdmin.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='room_id', full_name='proto.GroupAddAdmin.room_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='member_id', full_name='proto.GroupAddAdmin.member_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='permission', full_name='proto.GroupAddAdmin.permission', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_GROUPADDADMIN_ADMINRIGHTS, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=62,
  serialized_end=361,
)


_GROUPADDADMINRESPONSE = _descriptor.Descriptor(
  name='GroupAddAdminResponse',
  full_name='proto.GroupAddAdminResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.GroupAddAdminResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='room_id', full_name='proto.GroupAddAdminResponse.room_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='member_id', full_name='proto.GroupAddAdminResponse.member_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='permission', full_name='proto.GroupAddAdminResponse.permission', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=364,
  serialized_end=512,
)

_GROUPADDADMIN_ADMINRIGHTS.containing_type = _GROUPADDADMIN
_GROUPADDADMIN.fields_by_name['request'].message_type = Request__pb2._REQUEST
_GROUPADDADMIN.fields_by_name['permission'].message_type = _GROUPADDADMIN_ADMINRIGHTS
_GROUPADDADMINRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_GROUPADDADMINRESPONSE.fields_by_name['permission'].message_type = _GROUPADDADMIN_ADMINRIGHTS
DESCRIPTOR.message_types_by_name['GroupAddAdmin'] = _GROUPADDADMIN
DESCRIPTOR.message_types_by_name['GroupAddAdminResponse'] = _GROUPADDADMINRESPONSE

GroupAddAdmin = _reflection.GeneratedProtocolMessageType('GroupAddAdmin', (_message.Message,), dict(

  AdminRights = _reflection.GeneratedProtocolMessageType('AdminRights', (_message.Message,), dict(
    DESCRIPTOR = _GROUPADDADMIN_ADMINRIGHTS,
    __module__ = 'GroupAddAdmin_pb2'
    # @@protoc_insertion_point(class_scope:proto.GroupAddAdmin.AdminRights)
    ))
  ,
  DESCRIPTOR = _GROUPADDADMIN,
  __module__ = 'GroupAddAdmin_pb2'
  # @@protoc_insertion_point(class_scope:proto.GroupAddAdmin)
  ))
_sym_db.RegisterMessage(GroupAddAdmin)
_sym_db.RegisterMessage(GroupAddAdmin.AdminRights)

GroupAddAdminResponse = _reflection.GeneratedProtocolMessageType('GroupAddAdminResponse', (_message.Message,), dict(
  DESCRIPTOR = _GROUPADDADMINRESPONSE,
  __module__ = 'GroupAddAdmin_pb2'
  # @@protoc_insertion_point(class_scope:proto.GroupAddAdminResponse)
  ))
_sym_db.RegisterMessage(GroupAddAdminResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\022ProtoGroupAddAdmin'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ClientGetPoll.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2
from ighap_bot.proto import Global_pb2 as Global__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ClientGetPoll.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x13\x43lientGetPoll.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\x1a\x0cGlobal.proto\"U\n\rClientGetPoll\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x0f\n\x07poll_id\x18\x02 \x01(\r\x12\x12\n\nproject_id\x18\x03 \x01(\r\"e\n\x15\x43lientGetPollResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\r\n\x05title\x18\x02 \x01(\t\x12\x1a\n\x05polls\x18\x03 \x03(\x0b\x32\x0b.proto.PollB$\n\x0enet.iGap.protoB\x12ProtoClientGetPollb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,Global__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_CLIENTGETPOLL = _descriptor.Descriptor(
  name='ClientGetPoll',
  full_name='proto.ClientGetPoll',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.ClientGetPoll.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='poll_id', full_name='proto.ClientGetPoll.poll_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='project_id', full_name='proto.ClientGetPoll.project_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=75,
  serialized_end=160,
)


_CLIENTGETPOLLRESPONSE = _descriptor.Descriptor(
  name='ClientGetPollResponse',
  full_name='proto.ClientGetPollResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.ClientGetPollResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='title', full_name='proto.ClientGetPollResponse.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='polls', full_name='proto.ClientGetPollResponse.polls', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=162,
  serialized_end=263,
)

_CLIENTGETPOLL.fields_by_name['request'].message_type = Request__pb2._REQUEST
_CLIENTGETPOLLRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_CLIENTGETPOLLRESPONSE.fields_by_name['polls'].message_type = Global__pb2._POLL
DESCRIPTOR.message_types_by_name['ClientGetPoll'] = _CLIENTGETPOLL
DESCRIPTOR.message_types_by_name['ClientGetPollResponse'] = _CLIENTGETPOLLRESPONSE

ClientGetPoll = _reflection.GeneratedProtocolMessageType('ClientGetPoll', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTGETPOLL,
  __module__ = 'ClientGetPoll_pb2'
  # @@protoc_insertion_point(class_scope:proto.ClientGetPoll)
  ))
_sym_db.RegisterMessage(ClientGetPoll)

ClientGetPollResponse = _reflection.GeneratedProtocolMessageType('ClientGetPollResponse', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTGETPOLLRESPONSE,
  __module__ = 'ClientGetPoll_pb2'
  # @@protoc_insertion_point(class_scope:proto.ClientGetPollResponse)
  ))
_sym_db.RegisterMessage(ClientGetPollResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\022ProtoClientGetPoll'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: WalletGetAccessToken.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='WalletGetAccessToken.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x1aWalletGetAccessToken.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"7\n\x14WalletGetAccessToken\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\"\xc7\x01\n\x1cWalletGetAccessTokenResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x41\n\ntoken_type\x18\x02 \x01(\x0e\x32-.proto.WalletGetAccessTokenResponse.TokenType\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x03 \x01(\t\x12\x12\n\nexpires_in\x18\x04 \x01(\r\"\x17\n\tTokenType\x12\n\n\x06\x42\x45\x41RER\x10\x00\x42+\n\x0enet.iGap.protoB\x19ProtoWalletGetAccessTokenb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_WALLETGETACCESSTOKENRESPONSE_TOKENTYPE = _descriptor.EnumDescriptor(
  name='TokenType',
  full_name='proto.WalletGetAccessTokenResponse.TokenType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BEARER', index=0, number=0,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=302,
  serialized_end=325,
)
_sym_db.RegisterEnumDescriptor(_WALLETGETACCESSTOKENRESPONSE_TOKENTYPE)


_WALLETGETACCESSTOKEN = _descriptor.Descriptor(
  name='WalletGetAccessToken',
  full_name='proto.WalletGetAccessToken',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.WalletGetAccessToken.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=68,
  serialized_end=123,
)


_WALLETGETACCESSTOKENRESPONSE = _descriptor.Descriptor(
  name='WalletGetAccessTokenResponse',
  full_name='proto.WalletGetAccessTokenResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.WalletGetAccessTokenResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='token_type', full_name='proto.WalletGetAccessTokenResponse.token_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='access_token', full_name='proto.WalletGetAccessTokenResponse.access_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='expires_in', full_name='proto.WalletGetAccessTokenResponse.expires_in', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _WALLETGETACCESSTOKENRESPONSE_TOKENTYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=126,
  serialized_end=325,
)

_WALLETGETACCESSTOKEN.fields_by_name['request'].message_type = Request__pb2._REQUEST
_WALLETGETACCESSTOKENRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_WALLETGETACCESSTOKENRESPONSE.fields_by_name['token_type'].enum_type = _WALLETGETACCESSTOKENRESPONSE_TOKENTYPE
_WALLETGETACCESSTOKENRESPONSE_TOKENTYPE.containing_type = _WALLETGETACCESSTOKENRESPONSE
DESCRIPTOR.message_types_by_name['WalletGetAccessToken'] = _WALLETGETACCESSTOKEN
DESCRIPTOR.message_types_by_name['WalletGetAccessTokenResponse'] = _WALLETGETACCESSTOKENRESPONSE

WalletGetAccessToken = _reflection.GeneratedProtocolMessageType('WalletGetAccessToken', (_message.Message,), dict(
  DESCRIPTOR = _WALLETGETACCESSTOKEN,
  __module__ = 'WalletGetAccessToken_pb2'
  # @@protoc_insertion_point(class_scope:proto.WalletGetAccessToken)
  ))
_sym_db.RegisterMessage(WalletGetAccessToken)

WalletGetAccessTokenResponse = _reflection.GeneratedProtocolMessageType('WalletGetAccessTokenResponse', (_message.Message,), dict(
  DESCRIPTOR = _WALLETGETACCESSTOKENRESPONSE,
  __module__ = 'WalletGetAccessToken_pb2'
  # @@protoc_insertion_point(class_scope:proto.WalletGetAccessTokenResponse)
  ))
_sym_db.RegisterMessage(WalletGetAccessTokenResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\031ProtoWalletGetAccessToken'))
# @@protoc_insertion_point(module_scope)
